# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/hook/hook.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5dbtlabs/proto/public/v1/events/fusion/hook/hook.proto\x12\x1cv1.public.events.fusion.hook\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\xbf\x02\n\rHookProcessed\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x39\n\thook_type\x18\x03 \x01(\x0e\x32&.v1.public.events.fusion.hook.HookType\x12\x12\n\nhook_index\x18\x04 \x01(\r\x12\x11\n\tunique_id\x18\x05 \x01(\t\x12?\n\x0chook_outcome\x18\x06 \x01(\x0e\x32).v1.public.events.fusion.hook.HookOutcome\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x07 \x01(\t\x12<\n\x05phase\x18\x08 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseB\x07\n\x05_name*\x8c\x01\n\x08HookType\x12\x19\n\x15HOOK_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16HOOK_TYPE_ON_RUN_START\x10\x01\x12\x18\n\x14HOOK_TYPE_ON_RUN_END\x10\x02\x12\x16\n\x12HOOK_TYPE_PRE_HOOK\x10\x03\x12\x17\n\x13HOOK_TYPE_POST_HOOK\x10\x04*x\n\x0bHookOutcome\x12\x1c\n\x18HOOK_OUTCOME_UNSPECIFIED\x10\x00\x12\x18\n\x14HOOK_OUTCOME_SUCCESS\x10\x01\x12\x16\n\x12HOOK_OUTCOME_ERROR\x10\x02\x12\x19\n\x15HOOK_OUTCOME_CANCELED\x10\x03\x42?Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/hookb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.hook.hook_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/hook'
  _globals['_HOOKTYPE']._serialized_start=467
  _globals['_HOOKTYPE']._serialized_end=607
  _globals['_HOOKOUTCOME']._serialized_start=609
  _globals['_HOOKOUTCOME']._serialized_end=729
  _globals['_HOOKPROCESSED']._serialized_start=145
  _globals['_HOOKPROCESSED']._serialized_end=464
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HookType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HookTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HookType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HOOK_TYPE_UNSPECIFIED: _HookType.ValueType  # 0
    HOOK_TYPE_ON_RUN_START: _HookType.ValueType  # 1
    """on-run-start hook configured in the project"""
    HOOK_TYPE_ON_RUN_END: _HookType.ValueType  # 2
    """on-run-end hook configured in the project"""
    HOOK_TYPE_PRE_HOOK: _HookType.ValueType  # 3
    """pre-hook executed before a specific node"""
    HOOK_TYPE_POST_HOOK: _HookType.ValueType  # 4
    """post-hook executed after a specific node"""

class HookType(_HookType, metaclass=_HookTypeEnumTypeWrapper):
    """Hook type indicating which hook this is"""

HOOK_TYPE_UNSPECIFIED: HookType.ValueType  # 0
HOOK_TYPE_ON_RUN_START: HookType.ValueType  # 1
"""on-run-start hook configured in the project"""
HOOK_TYPE_ON_RUN_END: HookType.ValueType  # 2
"""on-run-end hook configured in the project"""
HOOK_TYPE_PRE_HOOK: HookType.ValueType  # 3
"""pre-hook executed before a specific node"""
HOOK_TYPE_POST_HOOK: HookType.ValueType  # 4
"""post-hook executed after a specific node"""
Global___HookType: typing_extensions.TypeAlias = HookType

class _HookOutcome:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HookOutcomeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HookOutcome.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HOOK_OUTCOME_UNSPECIFIED: _HookOutcome.ValueType  # 0
    HOOK_OUTCOME_SUCCESS: _HookOutcome.ValueType  # 1
    """Hook completed successfully"""
    HOOK_OUTCOME_ERROR: _HookOutcome.ValueType  # 2
    """Hook failed with an error"""
    HOOK_OUTCOME_CANCELED: _HookOutcome.ValueType  # 3
    """Hook was canceled (e.g. user-initiated cancellation)"""

class HookOutcome(_HookOutcome, metaclass=_HookOutcomeEnumTypeWrapper):
    """Hook outcome for a single hook execution"""

HOOK_OUTCOME_UNSPECIFIED: HookOutcome.ValueType  # 0
HOOK_OUTCOME_SUCCESS: HookOutcome.ValueType  # 1
"""Hook completed successfully"""
HOOK_OUTCOME_ERROR: HookOutcome.ValueType  # 2
"""Hook failed with an error"""
HOOK_OUTCOME_CANCELED: HookOutcome.ValueType  # 3
"""Hook was canceled (e.g. user-initiated cancellation)"""
Global___HookOutcome: typing_extensions.TypeAlias = HookOutcome

@typing.final
class HookProcessed(google.protobuf.message.Message):
    """Span event tracking execution of a single hook (operation).
    Maps to dbt-core's LogHookStartLine (Q032) and LogHookEndLine (Q033) events.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    HOOK_TYPE_FIELD_NUMBER: builtins.int
    HOOK_INDEX_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    HOOK_OUTCOME_FIELD_NUMBER: builtins.int
    DBT_CORE_EVENT_CODE_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    """Package name that owns this hook."""
    name: builtins.str
    """Hook name (applicable for on-run-start/on-run-end hooks)"""
    hook_type: Global___HookType.ValueType
    """Type of hook being executed"""
    hook_index: builtins.int
    """0-based index in the execution order of this hook category (for example, within on-run-start).
    This index is global across dependencies and current project.
    """
    unique_id: builtins.str
    """unique_id of the associated node (for pre/post hooks)
    unique_id of the hook itself for on-run-start/on-run-end hooks
    """
    hook_outcome: Global___HookOutcome.ValueType
    """Outcome of the hook execution"""
    dbt_core_event_code: builtins.str
    """Legacy dbt core event code. Set to Q032 for start, Q033 for end."""
    phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType
    """Execution phase in which this hook ran."""
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str | None = ...,
        hook_type: Global___HookType.ValueType = ...,
        hook_index: builtins.int = ...,
        unique_id: builtins.str = ...,
        hook_outcome: Global___HookOutcome.ValueType = ...,
        dbt_core_event_code: builtins.str = ...,
        phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_name", b"_name", "name", b"name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_name", b"_name", "dbt_core_event_code", b"dbt_core_event_code", "hook_index", b"hook_index", "hook_outcome", b"hook_outcome", "hook_type", b"hook_type", "name", b"name", "package_name", b"package_name", "phase", b"phase", "unique_id", b"unique_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_name", b"_name"]) -> typing.Literal["name"] | None: ...

Global___HookProcessed: typing_extensions.TypeAlias = HookProcessed



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _OnboardingScreen:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OnboardingScreenEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OnboardingScreen.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ONBOARDING_SCREEN_UNSPECIFIED: _OnboardingScreen.ValueType  # 0
    ONBOARDING_SCREEN_WELCOME: _OnboardingScreen.ValueType  # 1
    ONBOARDING_SCREEN_PROFILE_CHECK: _OnboardingScreen.ValueType  # 2
    ONBOARDING_SCREEN_PROFILE_FOUND: _OnboardingScreen.ValueType  # 3
    ONBOARDING_SCREEN_PROFILE_SETUP: _OnboardingScreen.ValueType  # 4
    ONBOARDING_SCREEN_LINK_ACCOUNT: _OnboardingScreen.ValueType  # 5
    ONBOARDING_SCREEN_DBT_PARSE: _OnboardingScreen.ValueType  # 6
    ONBOARDING_SCREEN_PARSE_ERROR_AUTOFIX: _OnboardingScreen.ValueType  # 7
    ONBOARDING_SCREEN_DBT_PARSE_RETRY: _OnboardingScreen.ValueType  # 8
    ONBOARDING_SCREEN_PARSE_ERROR_FAIL: _OnboardingScreen.ValueType  # 9
    ONBOARDING_SCREEN_COMPILE_NO_SA: _OnboardingScreen.ValueType  # 10
    ONBOARDING_SCREEN_COMPILE_NO_SA_FAIL: _OnboardingScreen.ValueType  # 11
    ONBOARDING_SCREEN_COMPILE: _OnboardingScreen.ValueType  # 12
    ONBOARDING_SCREEN_COMPILE_FAIL: _OnboardingScreen.ValueType  # 13
    ONBOARDING_SCREEN_SUCCESS: _OnboardingScreen.ValueType  # 14
    ONBOARDING_SCREEN_AGENTIC_AUTOFIX: _OnboardingScreen.ValueType  # 15
    ONBOARDING_SCREEN_TRY_AGENTIC_AUTOFIX: _OnboardingScreen.ValueType  # 16
    ONBOARDING_SCREEN_DOWNLOAD_AGENTS_MD: _OnboardingScreen.ValueType  # 17
    ONBOARDING_SCREEN_COMPILE_SA_BASELINE: _OnboardingScreen.ValueType  # 18
    ONBOARDING_SCREEN_COMPILE_SA_BASELINE_SUCCESS: _OnboardingScreen.ValueType  # 19

class OnboardingScreen(_OnboardingScreen, metaclass=_OnboardingScreenEnumTypeWrapper): ...

ONBOARDING_SCREEN_UNSPECIFIED: OnboardingScreen.ValueType  # 0
ONBOARDING_SCREEN_WELCOME: OnboardingScreen.ValueType  # 1
ONBOARDING_SCREEN_PROFILE_CHECK: OnboardingScreen.ValueType  # 2
ONBOARDING_SCREEN_PROFILE_FOUND: OnboardingScreen.ValueType  # 3
ONBOARDING_SCREEN_PROFILE_SETUP: OnboardingScreen.ValueType  # 4
ONBOARDING_SCREEN_LINK_ACCOUNT: OnboardingScreen.ValueType  # 5
ONBOARDING_SCREEN_DBT_PARSE: OnboardingScreen.ValueType  # 6
ONBOARDING_SCREEN_PARSE_ERROR_AUTOFIX: OnboardingScreen.ValueType  # 7
ONBOARDING_SCREEN_DBT_PARSE_RETRY: OnboardingScreen.ValueType  # 8
ONBOARDING_SCREEN_PARSE_ERROR_FAIL: OnboardingScreen.ValueType  # 9
ONBOARDING_SCREEN_COMPILE_NO_SA: OnboardingScreen.ValueType  # 10
ONBOARDING_SCREEN_COMPILE_NO_SA_FAIL: OnboardingScreen.ValueType  # 11
ONBOARDING_SCREEN_COMPILE: OnboardingScreen.ValueType  # 12
ONBOARDING_SCREEN_COMPILE_FAIL: OnboardingScreen.ValueType  # 13
ONBOARDING_SCREEN_SUCCESS: OnboardingScreen.ValueType  # 14
ONBOARDING_SCREEN_AGENTIC_AUTOFIX: OnboardingScreen.ValueType  # 15
ONBOARDING_SCREEN_TRY_AGENTIC_AUTOFIX: OnboardingScreen.ValueType  # 16
ONBOARDING_SCREEN_DOWNLOAD_AGENTS_MD: OnboardingScreen.ValueType  # 17
ONBOARDING_SCREEN_COMPILE_SA_BASELINE: OnboardingScreen.ValueType  # 18
ONBOARDING_SCREEN_COMPILE_SA_BASELINE_SUCCESS: OnboardingScreen.ValueType  # 19
Global___OnboardingScreen: typing_extensions.TypeAlias = OnboardingScreen

@typing.final
class OnboardingScreenShown(google.protobuf.message.Message):
    """Onboarding step event."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCREEN_FIELD_NUMBER: builtins.int
    screen: Global___OnboardingScreen.ValueType
    """Onboarding screen identifier"""
    def __init__(
        self,
        *,
        screen: Global___OnboardingScreen.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["screen", b"screen"]) -> None: ...

Global___OnboardingScreenShown: typing_extensions.TypeAlias = OnboardingScreenShown



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/onboarding/onboarding.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAdbtlabs/proto/public/v1/events/fusion/onboarding/onboarding.proto\x12\"v1.public.events.fusion.onboarding\"]\n\x15OnboardingScreenShown\x12\x44\n\x06screen\x18\x01 \x01(\x0e\x32\x34.v1.public.events.fusion.onboarding.OnboardingScreen*\x8d\x06\n\x10OnboardingScreen\x12!\n\x1dONBOARDING_SCREEN_UNSPECIFIED\x10\x00\x12\x1d\n\x19ONBOARDING_SCREEN_WELCOME\x10\x01\x12#\n\x1fONBOARDING_SCREEN_PROFILE_CHECK\x10\x02\x12#\n\x1fONBOARDING_SCREEN_PROFILE_FOUND\x10\x03\x12#\n\x1fONBOARDING_SCREEN_PROFILE_SETUP\x10\x04\x12\"\n\x1eONBOARDING_SCREEN_LINK_ACCOUNT\x10\x05\x12\x1f\n\x1bONBOARDING_SCREEN_DBT_PARSE\x10\x06\x12)\n%ONBOARDING_SCREEN_PARSE_ERROR_AUTOFIX\x10\x07\x12%\n!ONBOARDING_SCREEN_DBT_PARSE_RETRY\x10\x08\x12&\n\"ONBOARDING_SCREEN_PARSE_ERROR_FAIL\x10\t\x12#\n\x1fONBOARDING_SCREEN_COMPILE_NO_SA\x10\n\x12(\n$ONBOARDING_SCREEN_COMPILE_NO_SA_FAIL\x10\x0b\x12\x1d\n\x19ONBOARDING_SCREEN_COMPILE\x10\x0c\x12\"\n\x1eONBOARDING_SCREEN_COMPILE_FAIL\x10\r\x12\x1d\n\x19ONBOARDING_SCREEN_SUCCESS\x10\x0e\x12%\n!ONBOARDING_SCREEN_AGENTIC_AUTOFIX\x10\x0f\x12)\n%ONBOARDING_SCREEN_TRY_AGENTIC_AUTOFIX\x10\x10\x12(\n$ONBOARDING_SCREEN_DOWNLOAD_AGENTS_MD\x10\x11\x12)\n%ONBOARDING_SCREEN_COMPILE_SA_BASELINE\x10\x12\x12\x31\n-ONBOARDING_SCREEN_COMPILE_SA_BASELINE_SUCCESS\x10\x13\x42\x45ZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/onboardingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.onboarding.onboarding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/onboarding'
  _globals['_ONBOARDINGSCREEN']._serialized_start=201
  _globals['_ONBOARDINGSCREEN']._serialized_end=982
  _globals['_ONBOARDINGSCREENSHOWN']._serialized_start=105
  _globals['_ONBOARDINGSCREENSHOWN']._serialized_end=198
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/log/show_result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;dbtlabs/proto/public/v1/events/fusion/log/show_result.proto\x12\x1bv1.public.events.fusion.log\"\xb3\x01\n\nShowResult\x12J\n\routput_format\x18\x01 \x01(\x0e\x32\x33.v1.public.events.fusion.log.ShowResultOutputFormat\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x13\n\x0bresult_type\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_unique_id*g\n\x16ShowResultOutputFormat\x12)\n%SHOW_RESULT_OUTPUT_FORMAT_UNSPECIFIED\x10\x00\x12\"\n\x1eSHOW_RESULT_OUTPUT_FORMAT_TEXT\x10\x01\x42>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/logb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.log.show_result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/log'
  _globals['_SHOWRESULTOUTPUTFORMAT']._serialized_start=274
  _globals['_SHOWRESULTOUTPUTFORMAT']._serialized_end=377
  _globals['_SHOWRESULT']._serialized_start=93
  _globals['_SHOWRESULT']._serialized_end=272
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AssetParsed(google.protobuf.message.Message):
    """Span event tracking parsing of a single asset."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RELATIVE_PATH_FIELD_NUMBER: builtins.int
    DISPLAY_PATH_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    """Package name that owns this asset."""
    name: builtins.str
    """Asset name (typically the file stem)."""
    relative_path: builtins.str
    """Path to the asset relative to the project root."""
    display_path: builtins.str
    """Display path used for CLI progress output."""
    unique_id: builtins.str
    """Unique identifier for this asset when available."""
    phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType
    """Execution phase for this event."""
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        name: builtins.str = ...,
        relative_path: builtins.str = ...,
        display_path: builtins.str = ...,
        unique_id: builtins.str | None = ...,
        phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "unique_id", b"unique_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "display_path", b"display_path", "name", b"name", "package_name", b"package_name", "phase", b"phase", "relative_path", b"relative_path", "unique_id", b"unique_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_unique_id", b"_unique_id"]) -> typing.Literal["unique_id"] | None: ...

Global___AssetParsed: typing_extensions.TypeAlias = AssetParsed



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/generic/generic.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;dbtlabs/proto/public/v1/events/fusion/generic/generic.proto\x12\x1fv1.public.events.fusion.generic\"u\n\x11GenericOpExecuted\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x16\n\x0e\x64isplay_action\x18\x02 \x01(\t\x12\x1d\n\x10item_count_total\x18\x03 \x01(\x04H\x00\x88\x01\x01\x42\x13\n\x11_item_count_total\"\x85\x01\n\x16GenericOpItemProcessed\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\"\n\x1a\x64isplay_in_progress_action\x18\x02 \x01(\t\x12!\n\x19\x64isplay_on_success_action\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\tBBZ@github.com/dbt-labs/proto-golang/v1/public/events/fusion/genericb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.generic.generic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z@github.com/dbt-labs/proto-golang/v1/public/events/fusion/generic'
  _globals['_GENERICOPEXECUTED']._serialized_start=96
  _globals['_GENERICOPEXECUTED']._serialized_end=213
  _globals['_GENERICOPITEMPROCESSED']._serialized_start=216
  _globals['_GENERICOPITEMPROCESSED']._serialized_end=349
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CompiledCode(google.protobuf.message.Message):
    """Log event that carries compiled SQL for a project node.

    `sql` may contain user data and may be scrubbed when sensitive telemetry
    collection is disabled.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATIVE_PATH_FIELD_NUMBER: builtins.int
    SQL_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    relative_path: builtins.str
    """Path to the compiled SQL file, relative to project root (`in_dir`)."""
    sql: builtins.str
    """Compiled SQL text. May be scrubbed."""
    unique_id: builtins.str
    """Globally unique dbt node identifier."""
    node_name: builtins.str
    """Display node name for compatibility output."""
    def __init__(
        self,
        *,
        relative_path: builtins.str = ...,
        sql: builtins.str = ...,
        unique_id: builtins.str = ...,
        node_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_name", b"node_name", "relative_path", b"relative_path", "sql", b"sql", "unique_id", b"unique_id"]) -> None: ...

Global___CompiledCode: typing_extensions.TypeAlias = CompiledCode

@typing.final
class CompiledCodeInline(google.protobuf.message.Message):
    """Log event that carries inline compiled SQL code."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_FIELD_NUMBER: builtins.int
    sql: builtins.str
    def __init__(
        self,
        *,
        sql: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sql", b"sql"]) -> None: ...

Global___CompiledCodeInline: typing_extensions.TypeAlias = CompiledCodeInline



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/asset/asset.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dbtlabs/proto/public/v1/events/fusion/asset/asset.proto\x12\x1dv1.public.events.fusion.asset\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\xc2\x01\n\x0b\x41ssetParsed\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rrelative_path\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_path\x18\x04 \x01(\t\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x00\x88\x01\x01\x12<\n\x05phase\x18\x06 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseB\x0c\n\n_unique_idB@Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/assetb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.asset.asset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/asset'
  _globals['_ASSETPARSED']._serialized_start=148
  _globals['_ASSETPARSED']._serialized_end=342
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ShowResultOutputFormat:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ShowResultOutputFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ShowResultOutputFormat.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SHOW_RESULT_OUTPUT_FORMAT_UNSPECIFIED: _ShowResultOutputFormat.ValueType  # 0
    SHOW_RESULT_OUTPUT_FORMAT_TEXT: _ShowResultOutputFormat.ValueType  # 1
    """Pretty-printed text format suitable for terminal display."""

class ShowResultOutputFormat(_ShowResultOutputFormat, metaclass=_ShowResultOutputFormatEnumTypeWrapper):
    """Output format for ShowResult content."""

SHOW_RESULT_OUTPUT_FORMAT_UNSPECIFIED: ShowResultOutputFormat.ValueType  # 0
SHOW_RESULT_OUTPUT_FORMAT_TEXT: ShowResultOutputFormat.ValueType  # 1
"""Pretty-printed text format suitable for terminal display."""
Global___ShowResultOutputFormat: typing_extensions.TypeAlias = ShowResultOutputFormat

@typing.final
class ShowResult(google.protobuf.message.Message):
    """Event emitted when displaying verbose/diagnostic output controlled by --show flag.
    This includes internal structures like manifests, schedules, stats, task graphs, etc.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    RESULT_TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    output_format: Global___ShowResultOutputFormat.ValueType
    """Format of the output content."""
    content: builtins.str
    """The content to display in the specified format."""
    result_type: builtins.str
    """Type/category of the result being shown (e.g., "manifest", "schedule", "stats").
    This is expected to be a short identifier.
    """
    title: builtins.str
    """Title to display above the content. This should NOT include ANSI color codes -
    coloring is applied by the output layers.
    """
    unique_id: builtins.str
    """The unique_id of the node for which information is being shown, if applicable.
    Unset for non-node-specific results like manifest or schedule.
    """
    def __init__(
        self,
        *,
        output_format: Global___ShowResultOutputFormat.ValueType = ...,
        content: builtins.str = ...,
        result_type: builtins.str = ...,
        title: builtins.str = ...,
        unique_id: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "unique_id", b"unique_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "content", b"content", "output_format", b"output_format", "result_type", b"result_type", "title", b"title", "unique_id", b"unique_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_unique_id", b"_unique_id"]) -> typing.Literal["unique_id"] | None: ...

Global___ShowResult: typing_extensions.TypeAlias = ShowResult



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/process/process.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;dbtlabs/proto/public/v1/events/fusion/process/process.proto\x12\x1fv1.public.events.fusion.process\"O\n\x07Process\x12\x0f\n\x07package\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x0f\n\x07host_os\x18\x05 \x01(\t\x12\x11\n\thost_arch\x18\x06 \x01(\tBBZ@github.com/dbt-labs/proto-golang/v1/public/events/fusion/processb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.process.process_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z@github.com/dbt-labs/proto-golang/v1/public/events/fusion/process'
  _globals['_PROCESS']._serialized_start=96
  _globals['_PROCESS']._serialized_end=175
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GenericOpExecuted(google.protobuf.message.Message):
    """Note: These events are for operations whose API is not yet stabilized.
    They provide a generic progress tracking mechanism that can be used
    by various commands without requiring dedicated structured events.

    An event used for spans that represent the execution of an operation
    that doesn't have a stable API and/or dedicated event type with
    structured fields yet.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_ID_FIELD_NUMBER: builtins.int
    DISPLAY_ACTION_FIELD_NUMBER: builtins.int
    ITEM_COUNT_TOTAL_FIELD_NUMBER: builtins.int
    operation_id: builtins.str
    """Identifier for this operation type (e.g., "format", "lint")
    Used as unique ID for associating child items
    """
    display_action: builtins.str
    """Display action text in lowercase (e.g., "formatting", "linting").

    Note: this may be capitalized when rendered and/or combined with
    other text (e.g., "Started formatting 3 items...")
    """
    item_count_total: builtins.int
    """Total count of items (enables progress bar if > 0, otherwise spinner)"""
    def __init__(
        self,
        *,
        operation_id: builtins.str = ...,
        display_action: builtins.str = ...,
        item_count_total: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_item_count_total", b"_item_count_total", "item_count_total", b"item_count_total"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_item_count_total", b"_item_count_total", "display_action", b"display_action", "item_count_total", b"item_count_total", "operation_id", b"operation_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_item_count_total", b"_item_count_total"]) -> typing.Literal["item_count_total"] | None: ...

Global___GenericOpExecuted: typing_extensions.TypeAlias = GenericOpExecuted

@typing.final
class GenericOpItemProcessed(google.protobuf.message.Message):
    """An event used for spans emitted for each item processed as part of a
    GenericOpExecuted operation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATION_ID_FIELD_NUMBER: builtins.int
    DISPLAY_IN_PROGRESS_ACTION_FIELD_NUMBER: builtins.int
    DISPLAY_ON_SUCCESS_ACTION_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    operation_id: builtins.str
    """Must match the parent GenericOpExecuted.operation_id
    Used to look up UID from the global mapping
    """
    display_in_progress_action: builtins.str
    """Action text in lowercase (e.g., "formatting", "linting").
    for in-progress display.

    Note: this may be capitalized when rendered and/or combined with
    other text (e.g., "Started formatting {target}")
    """
    display_on_success_action: builtins.str
    """Action text in lowercase (e.g., "formatted", "linted").
    for on-success display.

    Note: this may be capitalized when rendered and/or combined with
    other text (e.g., "Formatted {target}")
    """
    target: builtins.str
    """Display name shown in progress bar context (e.g., file path)"""
    def __init__(
        self,
        *,
        operation_id: builtins.str = ...,
        display_in_progress_action: builtins.str = ...,
        display_on_success_action: builtins.str = ...,
        target: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["display_in_progress_action", b"display_in_progress_action", "display_on_success_action", b"display_on_success_action", "operation_id", b"operation_id", "target", b"target"]) -> None: ...

Global___GenericOpItemProcessed: typing_extensions.TypeAlias = GenericOpItemProcessed
